From: Wei Yongjun <[email protected]>

Using list_move_tail() instead of list_del() + list_add_tail().

Signed-off-by: Wei Yongjun <[email protected]>
---
 drivers/usb/wusbcore/wa-xfer.c | 6 ++----
 1 file changed, 2 insertions(+), 4 deletions(-)

diff --git a/drivers/usb/wusbcore/wa-xfer.c b/drivers/usb/wusbcore/wa-xfer.c
index 6ad02f5..cf10979 100644
--- a/drivers/usb/wusbcore/wa-xfer.c
+++ b/drivers/usb/wusbcore/wa-xfer.c
@@ -1552,10 +1552,8 @@ error_complete:
 
                dev_info(dev, "Control EP stall.  Queue delayed work.\n");
                spin_lock_irq(&wa->xfer_list_lock);
-               /* remove xfer from xfer_list. */
-               list_del(&xfer->list_node);
-               /* add xfer to xfer_errored_list. */
-               list_add_tail(&xfer->list_node, &wa->xfer_errored_list);
+               /* move xfer from xfer_list to xfer_errored_list. */
+               list_move_tail(&xfer->list_node, &wa->xfer_errored_list);
                spin_unlock_irq(&wa->xfer_list_lock);
                spin_unlock_irqrestore(&xfer->lock, flags);
                queue_work(wusbd, &wa->xfer_error_work);

--
To unsubscribe from this list: send the line "unsubscribe linux-usb" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to